@@ -184,7 +184,8 @@ class TestScriptDch(DebianGitTestRepo):
         """Test dch.py like gbp dch script does: new upstream version - snapshot - release"""
         options = ["--snapshot", "--release"]
         with capture_stderr() as c:
-            self.assertRaises(SystemExit, self.run_dch, options)
+            with self.assertRaises(SystemExit):
+                self.run_dch(options)
         self.assertTrue("'--snapshot' and '--release' are incompatible options" in c.output())
 
     def test_dch_main_new_upstream_version_with_distribution(self):
